
import sys
if sys.version_info >= (3, 8):
    from typing import Protocol
else:
    from typing_extensions import Protocol

import jpype
import jneqsim.neqsim.standards.gasQuality
import jneqsim.neqsim.standards.oilQuality
import jneqsim.neqsim.standards.salesContract
import jneqsim.neqsim.thermo.system
import jneqsim.neqsim.util
import typing



class StandardInterface:
    def calculate(self) -> None: ...
    def createTable(self, string: str) -> typing.MutableSequence[typing.MutableSequence[str]]: ...
    def display(self, string: str) -> None: ...
    def getName(self) -> str: ...
    def getReferencePressure(self) -> float: ...
    def getResultTable(self) -> typing.MutableSequence[typing.MutableSequence[str]]: ...
    def getSalesContract(self) -> jneqsim.neqsim.standards.salesContract.ContractInterface: ...
    def getStandardDescription(self) -> str: ...
    def getThermoSystem(self) -> jneqsim.neqsim.thermo.system.SystemInterface: ...
    def getUnit(self, string: str) -> str: ...
    @typing.overload
    def getValue(self, string: str) -> float: ...
    @typing.overload
    def getValue(self, string: str, string2: str) -> float: ...
    def isOnSpec(self) -> bool: ...
    def setReferencePressure(self, double: float) -> None: ...
    def setResultTable(self, stringArray: typing.Union[typing.List[typing.MutableSequence[str]], jpype.JArray]) -> None: ...
    @typing.overload
    def setSalesContract(self, string: str) -> None: ...
    @typing.overload
    def setSalesContract(self, contractInterface: jneqsim.neqsim.standards.salesContract.ContractInterface) -> None: ...
    def setThermoSystem(self, systemInterface: jneqsim.neqsim.thermo.system.SystemInterface) -> None: ...

class Standard(jneqsim.neqsim.util.NamedBaseClass, StandardInterface):
    @typing.overload
    def __init__(self, string: str, string2: str): ...
    @typing.overload
    def __init__(self, string: str, string2: str, systemInterface: jneqsim.neqsim.thermo.system.SystemInterface): ...
    def createTable(self, string: str) -> typing.MutableSequence[typing.MutableSequence[str]]: ...
    def display(self, string: str) -> None: ...
    def getReferencePressure(self) -> float: ...
    def getReferenceState(self) -> str: ...
    def getResultTable(self) -> typing.MutableSequence[typing.MutableSequence[str]]: ...
    def getSalesContract(self) -> jneqsim.neqsim.standards.salesContract.ContractInterface: ...
    def getStandardDescription(self) -> str: ...
    def getThermoSystem(self) -> jneqsim.neqsim.thermo.system.SystemInterface: ...
    def setReferencePressure(self, double: float) -> None: ...
    def setReferenceState(self, string: str) -> None: ...
    def setResultTable(self, stringArray: typing.Union[typing.List[typing.MutableSequence[str]], jpype.JArray]) -> None: ...
    @typing.overload
    def setSalesContract(self, string: str) -> None: ...
    @typing.overload
    def setSalesContract(self, contractInterface: jneqsim.neqsim.standards.salesContract.ContractInterface) -> None: ...
    def setStandardDescription(self, string: str) -> None: ...
    def setThermoSystem(self, systemInterface: jneqsim.neqsim.thermo.system.SystemInterface) -> None: ...


class __module_protocol__(Protocol):
    # A module protocol which reflects the result of ``jp.JPackage("jneqsim.neqsim.standards")``.

    Standard: typing.Type[Standard]
    StandardInterface: typing.Type[StandardInterface]
    gasQuality: jneqsim.neqsim.standards.gasQuality.__module_protocol__
    oilQuality: jneqsim.neqsim.standards.oilQuality.__module_protocol__
    salesContract: jneqsim.neqsim.standards.salesContract.__module_protocol__
