
import sys
if sys.version_info >= (3, 8):
    from typing import Protocol
else:
    from typing_extensions import Protocol

import java.io
import java.lang
import java.util
import jpype
import jneqsim.neqsim.chemicalReactions
import jneqsim.neqsim.physicalProperties.interfaceProperties
import jneqsim.neqsim.standards
import jneqsim.neqsim.thermo.characterization
import jneqsim.neqsim.thermo.component
import jneqsim.neqsim.thermo.phase
import typing



class SystemInterface(java.lang.Cloneable, java.io.Serializable):
    def addCapeOpenProperty(self, string: str) -> None: ...
    def addCharacterized(self, stringArray: typing.Union[typing.List[str], jpype.JArray], doubleArray: typing.Union[typing.List[float], jpype.JArray], doubleArray2: typing.Union[typing.List[float], jpype.JArray], doubleArray3: typing.Union[typing.List[float], jpype.JArray]) -> None: ...
    @typing.overload
    def addComponent(self, int: int, double: float) -> None: ...
    @typing.overload
    def addComponent(self, int: int, double: float, int2: int) -> None: ...
    @typing.overload
    def addComponent(self, string: str, double: float) -> None: ...
    @typing.overload
    def addComponent(self, string: str, double: float, double2: float, double3: float, double4: float) -> None: ...
    @typing.overload
    def addComponent(self, string: str, double: float, int: int) -> None: ...
    @typing.overload
    def addComponent(self, string: str, double: float, string2: str) -> None: ...
    @typing.overload
    def addComponent(self, string: str, double: float, string2: str, int: int) -> None: ...
    @typing.overload
    def addComponent(self, componentInterface: jneqsim.neqsim.thermo.component.ComponentInterface) -> None: ...
    @typing.overload
    def addComponent(self, string: str) -> None: ...
    @typing.overload
    def addComponents(self, stringArray: typing.Union[typing.List[str], jpype.JArray]) -> None: ...
    @typing.overload
    def addComponents(self, stringArray: typing.Union[typing.List[str], jpype.JArray], doubleArray: typing.Union[typing.List[float], jpype.JArray]) -> None: ...
    @typing.overload
    def addFluid(self, systemInterface: 'SystemInterface') -> 'SystemInterface': ...
    @typing.overload
    def addFluid(self, systemInterface: 'SystemInterface', int: int) -> 'SystemInterface': ...
    @staticmethod
    def addFluids(systemInterface: 'SystemInterface', systemInterface2: 'SystemInterface') -> 'SystemInterface': ...
    def addGasToLiquid(self, double: float) -> None: ...
    def addLiquidToGas(self, double: float) -> None: ...
    @typing.overload
    def addOilFractions(self, stringArray: typing.Union[typing.List[str], jpype.JArray], doubleArray: typing.Union[typing.List[float], jpype.JArray], doubleArray2: typing.Union[typing.List[float], jpype.JArray], doubleArray3: typing.Union[typing.List[float], jpype.JArray], boolean: bool) -> None: ...
    @typing.overload
    def addOilFractions(self, stringArray: typing.Union[typing.List[str], jpype.JArray], doubleArray: typing.Union[typing.List[float], jpype.JArray], doubleArray2: typing.Union[typing.List[float], jpype.JArray], doubleArray3: typing.Union[typing.List[float], jpype.JArray], boolean: bool, boolean2: bool, int: int) -> None: ...
    def addPhase(self) -> None: ...
    @typing.overload
    def addPhaseFractionToPhase(self, double: float, string: str, string2: str, string3: str) -> None: ...
    @typing.overload
    def addPhaseFractionToPhase(self, double: float, string: str, string2: str, string3: str, string4: str) -> None: ...
    def addPlusFraction(self, string: str, double: float, double2: float, double3: float) -> None: ...
    def addSalt(self, string: str, double: float) -> None: ...
    def addSolidComplexPhase(self, string: str) -> None: ...
    @typing.overload
    def addTBPfraction(self, string: str, double: float, double2: float, double3: float) -> None: ...
    @typing.overload
    def addTBPfraction(self, string: str, double: float, double2: float, double3: float, double4: float, double5: float, double6: float) -> None: ...
    def addToComponentNames(self, string: str) -> None: ...
    @typing.overload
    def allowPhaseShift(self) -> bool: ...
    @typing.overload
    def allowPhaseShift(self, boolean: bool) -> None: ...
    def autoSelectMixingRule(self) -> None: ...
    def autoSelectModel(self) -> 'SystemInterface': ...
    def calcBeta(self) -> float: ...
    def calcHenrysConstant(self, string: str) -> float: ...
    def calcInterfaceProperties(self) -> None: ...
    def calcKIJ(self, boolean: bool) -> None: ...
    def calcResultTable(self) -> typing.MutableSequence[typing.MutableSequence[str]]: ...
    def calc_x_y(self) -> None: ...
    def calc_x_y_nonorm(self) -> None: ...
    def changeComponentName(self, string: str, string2: str) -> None: ...
    @typing.overload
    def checkStability(self) -> bool: ...
    @typing.overload
    def checkStability(self, boolean: bool) -> None: ...
    def chemicalReactionInit(self) -> None: ...
    def clearAll(self) -> None: ...
    def clone(self) -> 'SystemInterface': ...
    def createDatabase(self, boolean: bool) -> None: ...
    def createTable(self, string: str) -> typing.MutableSequence[typing.MutableSequence[str]]: ...
    def deleteFluidPhase(self, int: int) -> None: ...
    @typing.overload
    def display(self, string: str) -> None: ...
    @typing.overload
    def display(self) -> None: ...
    def doMultiPhaseCheck(self) -> bool: ...
    def doSolidPhaseCheck(self) -> bool: ...
    def equals(self, object: typing.Any) -> bool: ...
    @typing.overload
    def getBeta(self) -> float: ...
    @typing.overload
    def getBeta(self, int: int) -> float: ...
    def getCASNumbers(self) -> typing.MutableSequence[str]: ...
    def getCapeOpenProperties10(self) -> typing.MutableSequence[str]: ...
    def getCapeOpenProperties11(self) -> typing.MutableSequence[str]: ...
    def getCharacterization(self) -> jneqsim.neqsim.thermo.characterization.Characterise: ...
    def getChemicalReactionOperations(self) -> jneqsim.neqsim.chemicalReactions.ChemicalReactionOperations: ...
    def getCompFormulaes(self) -> typing.MutableSequence[str]: ...
    def getCompIDs(self) -> typing.MutableSequence[str]: ...
    def getCompNames(self) -> typing.MutableSequence[str]: ...
    @typing.overload
    def getComponent(self, int: int) -> jneqsim.neqsim.thermo.component.ComponentInterface: ...
    @typing.overload
    def getComponent(self, string: str) -> jneqsim.neqsim.thermo.component.ComponentInterface: ...
    def getComponentNameTag(self) -> str: ...
    def getComponentNames(self) -> typing.MutableSequence[str]: ...
    def getCorrectedVolume(self) -> float: ...
    def getCorrectedVolumeFraction(self, int: int) -> float: ...
    @typing.overload
    def getCp(self) -> float: ...
    @typing.overload
    def getCp(self, string: str) -> float: ...
    @typing.overload
    def getCv(self) -> float: ...
    @typing.overload
    def getCv(self, string: str) -> float: ...
    @typing.overload
    def getDensity(self) -> float: ...
    @typing.overload
    def getDensity(self, string: str) -> float: ...
    def getEmptySystemClone(self) -> 'SystemInterface': ...
    @typing.overload
    def getEnthalpy(self) -> float: ...
    @typing.overload
    def getEnthalpy(self, string: str) -> float: ...
    @typing.overload
    def getEntropy(self) -> float: ...
    @typing.overload
    def getEntropy(self, string: str) -> float: ...
    @typing.overload
    def getExergy(self, double: float) -> float: ...
    @typing.overload
    def getExergy(self, double: float, string: str) -> float: ...
    def getFlowRate(self, string: str) -> float: ...
    def getFluidInfo(self) -> str: ...
    def getFluidName(self) -> str: ...
    def getGamma(self) -> float: ...
    def getGamma2(self) -> float: ...
    def getGasPhase(self) -> jneqsim.neqsim.thermo.phase.PhaseInterface: ...
    def getGibbsEnergy(self) -> float: ...
    def getHeatOfVaporization(self) -> float: ...
    def getHelmholtzEnergy(self) -> float: ...
    def getHydrateCheck(self) -> bool: ...
    def getIdealLiquidDensity(self, string: str) -> float: ...
    def getInitType(self) -> int: ...
    @typing.overload
    def getInterfacialTension(self, int: int, int2: int) -> float: ...
    @typing.overload
    def getInterfacialTension(self, int: int, int2: int, string: str) -> float: ...
    @typing.overload
    def getInterfacialTension(self, string: str, string2: str) -> float: ...
    @typing.overload
    def getInternalEnergy(self) -> float: ...
    @typing.overload
    def getInternalEnergy(self, string: str) -> float: ...
    def getInterphaseProperties(self) -> jneqsim.neqsim.physicalProperties.interfaceProperties.InterphasePropertiesInterface: ...
    @typing.overload
    def getJouleThomsonCoefficient(self) -> float: ...
    @typing.overload
    def getJouleThomsonCoefficient(self, string: str) -> float: ...
    def getKappa(self) -> float: ...
    @typing.overload
    def getKinematicViscosity(self) -> float: ...
    @typing.overload
    def getKinematicViscosity(self, string: str) -> float: ...
    def getLiquidPhase(self) -> jneqsim.neqsim.thermo.phase.PhaseInterface: ...
    def getLiquidVolume(self) -> float: ...
    def getLowestGibbsEnergyPhase(self) -> jneqsim.neqsim.thermo.phase.PhaseInterface: ...
    def getMass(self, string: str) -> float: ...
    def getMaxNumberOfPhases(self) -> int: ...
    def getMixingRule(self) -> int: ...
    def getMixingRuleName(self) -> str: ...
    def getModelName(self) -> str: ...
    def getMolarComposition(self) -> typing.MutableSequence[float]: ...
    @typing.overload
    def getMolarMass(self) -> float: ...
    @typing.overload
    def getMolarMass(self, string: str) -> float: ...
    def getMolarRate(self) -> typing.MutableSequence[float]: ...
    @typing.overload
    def getMolarVolume(self) -> float: ...
    @typing.overload
    def getMolarVolume(self, string: str) -> float: ...
    def getMoleFraction(self, int: int) -> float: ...
    def getMoleFractionsSum(self) -> float: ...
    def getMolecularWeights(self) -> typing.MutableSequence[float]: ...
    def getNormalBoilingPointTemperatures(self) -> typing.MutableSequence[float]: ...
    def getNumberOfComponents(self) -> int: ...
    def getNumberOfMoles(self) -> float: ...
    def getNumberOfOilFractionComponents(self) -> int: ...
    def getNumberOfPhases(self) -> int: ...
    def getOilFractionIDs(self) -> typing.MutableSequence[int]: ...
    def getOilFractionLiquidDensityAt25C(self) -> typing.MutableSequence[float]: ...
    def getOilFractionMolecularMass(self) -> typing.MutableSequence[float]: ...
    def getOilFractionNormalBoilingPoints(self) -> typing.MutableSequence[float]: ...
    def getPC(self) -> float: ...
    @typing.overload
    def getPhase(self, int: int) -> jneqsim.neqsim.thermo.phase.PhaseInterface: ...
    @typing.overload
    def getPhase(self, string: str) -> jneqsim.neqsim.thermo.phase.PhaseInterface: ...
    @typing.overload
    def getPhase(self, phaseType: jneqsim.neqsim.thermo.phase.PhaseType) -> jneqsim.neqsim.thermo.phase.PhaseInterface: ...
    def getPhaseFraction(self, string: str, string2: str) -> float: ...
    @typing.overload
    def getPhaseIndex(self, int: int) -> int: ...
    @typing.overload
    def getPhaseIndex(self, string: str) -> int: ...
    @typing.overload
    def getPhaseIndex(self, phaseInterface: jneqsim.neqsim.thermo.phase.PhaseInterface) -> int: ...
    @typing.overload
    def getPhaseNumberOfPhase(self, phaseType: jneqsim.neqsim.thermo.phase.PhaseType) -> int: ...
    @typing.overload
    def getPhaseNumberOfPhase(self, string: str) -> int: ...
    def getPhaseOfType(self, string: str) -> jneqsim.neqsim.thermo.phase.PhaseInterface: ...
    def getPhases(self) -> typing.MutableSequence[jneqsim.neqsim.thermo.phase.PhaseInterface]: ...
    @typing.overload
    def getPressure(self) -> float: ...
    @typing.overload
    def getPressure(self, int: int) -> float: ...
    @typing.overload
    def getPressure(self, string: str) -> float: ...
    def getProperties(self) -> 'SystemProperties': ...
    @typing.overload
    def getProperty(self, string: str) -> float: ...
    @typing.overload
    def getProperty(self, string: str, int: int) -> float: ...
    @typing.overload
    def getProperty(self, string: str, string2: str, int: int) -> float: ...
    def getResultTable(self) -> typing.MutableSequence[typing.MutableSequence[str]]: ...
    @typing.overload
    def getSoundSpeed(self) -> float: ...
    @typing.overload
    def getSoundSpeed(self, string: str) -> float: ...
    @typing.overload
    def getStandard(self) -> jneqsim.neqsim.standards.StandardInterface: ...
    @typing.overload
    def getStandard(self, string: str) -> jneqsim.neqsim.standards.StandardInterface: ...
    def getTC(self) -> float: ...
    @typing.overload
    def getTemperature(self) -> float: ...
    @typing.overload
    def getTemperature(self, int: int) -> float: ...
    @typing.overload
    def getTemperature(self, string: str) -> float: ...
    @typing.overload
    def getThermalConductivity(self) -> float: ...
    @typing.overload
    def getThermalConductivity(self, string: str) -> float: ...
    def getTotalNumberOfMoles(self) -> float: ...
    @typing.overload
    def getViscosity(self) -> float: ...
    @typing.overload
    def getViscosity(self, string: str) -> float: ...
    @typing.overload
    def getVolume(self) -> float: ...
    @typing.overload
    def getVolume(self, string: str) -> float: ...
    def getVolumeFraction(self, int: int) -> float: ...
    def getWaxCharacterisation(self) -> jneqsim.neqsim.thermo.characterization.WaxCharacterise: ...
    def getWaxModel(self) -> jneqsim.neqsim.thermo.characterization.WaxModelInterface: ...
    def getWtFraction(self, int: int) -> float: ...
    def getZ(self) -> float: ...
    def getdVdPtn(self) -> float: ...
    def getdVdTpn(self) -> float: ...
    @typing.overload
    def hasComponent(self, string: str) -> bool: ...
    @typing.overload
    def hasComponent(self, string: str, boolean: bool) -> bool: ...
    @typing.overload
    def hasPhaseType(self, phaseType: jneqsim.neqsim.thermo.phase.PhaseType) -> bool: ...
    @typing.overload
    def hasPhaseType(self, string: str) -> bool: ...
    def hasPlusFraction(self) -> bool: ...
    def hasSolidPhase(self) -> bool: ...
    def hashCode(self) -> int: ...
    @typing.overload
    def init(self, int: int) -> None: ...
    @typing.overload
    def init(self, int: int, int2: int) -> None: ...
    @typing.overload
    def init(self) -> None: ...
    def initBeta(self) -> None: ...
    def initNumeric(self) -> None: ...
    @typing.overload
    def initPhysicalProperties(self) -> None: ...
    @typing.overload
    def initPhysicalProperties(self, string: str) -> None: ...
    def initProperties(self) -> None: ...
    def initRefPhases(self) -> None: ...
    def initThermoProperties(self) -> None: ...
    def initTotalNumberOfMoles(self, double: float) -> None: ...
    def init_x_y(self) -> None: ...
    def invertPhaseTypes(self) -> None: ...
    @typing.overload
    def isChemicalSystem(self) -> bool: ...
    @typing.overload
    def isChemicalSystem(self, boolean: bool) -> None: ...
    def isForcePhaseTypes(self) -> bool: ...
    @typing.overload
    def isImplementedCompositionDeriativesofFugacity(self) -> bool: ...
    @typing.overload
    def isImplementedCompositionDeriativesofFugacity(self, boolean: bool) -> None: ...
    def isImplementedPressureDeriativesofFugacity(self) -> bool: ...
    def isImplementedTemperatureDeriativesofFugacity(self) -> bool: ...
    def isMultiphaseWaxCheck(self) -> bool: ...
    def isNumericDerivatives(self) -> bool: ...
    def isPhase(self, int: int) -> bool: ...
    def normalizeBeta(self) -> None: ...
    def orderByDensity(self) -> None: ...
    @typing.overload
    def phaseToSystem(self, int: int) -> 'SystemInterface': ...
    @typing.overload
    def phaseToSystem(self, int: int, int2: int) -> 'SystemInterface': ...
    @typing.overload
    def phaseToSystem(self, string: str) -> 'SystemInterface': ...
    @typing.overload
    def phaseToSystem(self, phaseInterface: jneqsim.neqsim.thermo.phase.PhaseInterface) -> 'SystemInterface': ...
    def prettyPrint(self) -> None: ...
    def reInitPhaseType(self) -> None: ...
    def readFluid(self, string: str) -> None: ...
    def readObject(self, int: int) -> 'SystemInterface': ...
    def readObjectFromFile(self, string: str, string2: str) -> 'SystemInterface': ...
    def removeComponent(self, string: str) -> None: ...
    def removePhase(self, int: int) -> None: ...
    def removePhaseKeepTotalComposition(self, int: int) -> None: ...
    def renameComponent(self, string: str, string2: str) -> None: ...
    def replacePhase(self, int: int, phaseInterface: jneqsim.neqsim.thermo.phase.PhaseInterface) -> None: ...
    def reset(self) -> None: ...
    def resetCharacterisation(self) -> None: ...
    def resetDatabase(self) -> None: ...
    def resetPhysicalProperties(self) -> None: ...
    def reset_x_y(self) -> None: ...
    def save(self, string: str) -> None: ...
    @typing.overload
    def saveFluid(self, int: int) -> None: ...
    @typing.overload
    def saveFluid(self, int: int, string: str) -> None: ...
    def saveObject(self, int: int, string: str) -> None: ...
    def saveObjectToFile(self, string: str, string2: str) -> None: ...
    def saveToDataBase(self) -> None: ...
    def setAllComponentsInPhase(self, int: int) -> None: ...
    def setAllPhaseType(self, phaseType: jneqsim.neqsim.thermo.phase.PhaseType) -> None: ...
    def setAttractiveTerm(self, int: int) -> None: ...
    @typing.overload
    def setBeta(self, double: float) -> None: ...
    @typing.overload
    def setBeta(self, int: int, double: float) -> None: ...
    def setBmixType(self, int: int) -> None: ...
    def setComponentNameTag(self, string: str) -> None: ...
    def setComponentNameTagOnNormalComponents(self, string: str) -> None: ...
    def setComponentNames(self, stringArray: typing.Union[typing.List[str], jpype.JArray]) -> None: ...
    def setEmptyFluid(self) -> None: ...
    def setFluidInfo(self, string: str) -> None: ...
    def setFluidName(self, string: str) -> None: ...
    def setForcePhaseTypes(self, boolean: bool) -> None: ...
    def setHeavyTBPfractionAsPlusFraction(self) -> bool: ...
    def setHydrateCheck(self, boolean: bool) -> None: ...
    def setImplementedCompositionDeriativesofFugacity(self, boolean: bool) -> None: ...
    def setImplementedPressureDeriativesofFugacity(self, boolean: bool) -> None: ...
    def setImplementedTemperatureDeriativesofFugacity(self, boolean: bool) -> None: ...
    def setInitType(self, int: int) -> None: ...
    def setMaxNumberOfPhases(self, int: int) -> None: ...
    @typing.overload
    def setMixingRule(self, int: int) -> None: ...
    @typing.overload
    def setMixingRule(self, string: str) -> None: ...
    @typing.overload
    def setMixingRule(self, string: str, string2: str) -> None: ...
    def setModel(self, string: str) -> 'SystemInterface': ...
    def setMolarComposition(self, doubleArray: typing.Union[typing.List[float], jpype.JArray]) -> None: ...
    def setMolarCompositionOfPlusFluid(self, doubleArray: typing.Union[typing.List[float], jpype.JArray]) -> None: ...
    def setMolarCompositionPlus(self, doubleArray: typing.Union[typing.List[float], jpype.JArray]) -> None: ...
    def setMolarFlowRates(self, doubleArray: typing.Union[typing.List[float], jpype.JArray]) -> None: ...
    def setMultiPhaseCheck(self, boolean: bool) -> None: ...
    def setMultiphaseWaxCheck(self, boolean: bool) -> None: ...
    def setNumberOfPhases(self, int: int) -> None: ...
    def setNumericDerivatives(self, boolean: bool) -> None: ...
    def setPC(self, double: float) -> None: ...
    def setPhase(self, phaseInterface: jneqsim.neqsim.thermo.phase.PhaseInterface, int: int) -> None: ...
    def setPhaseIndex(self, int: int, int2: int) -> None: ...
    @typing.overload
    def setPhaseType(self, int: int, string: str) -> None: ...
    @typing.overload
    def setPhaseType(self, int: int, phaseType: jneqsim.neqsim.thermo.phase.PhaseType) -> None: ...
    def setPhysicalPropertyModel(self, int: int) -> None: ...
    @typing.overload
    def setPressure(self, double: float) -> None: ...
    @typing.overload
    def setPressure(self, double: float, string: str) -> None: ...
    @typing.overload
    def setSolidPhaseCheck(self, boolean: bool) -> None: ...
    @typing.overload
    def setSolidPhaseCheck(self, string: str) -> None: ...
    def setStandard(self, string: str) -> None: ...
    def setTC(self, double: float) -> None: ...
    @typing.overload
    def setTemperature(self, double: float) -> None: ...
    @typing.overload
    def setTemperature(self, double: float, int: int) -> None: ...
    @typing.overload
    def setTemperature(self, double: float, string: str) -> None: ...
    def setTotalFlowRate(self, double: float, string: str) -> None: ...
    def setTotalNumberOfMoles(self, double: float) -> None: ...
    def setUseTVasIndependentVariables(self, boolean: bool) -> None: ...
    def tuneModel(self, string: str, double: float, int: int) -> None: ...
    def useVolumeCorrection(self, boolean: bool) -> None: ...
    def write(self, string: str, string2: str, boolean: bool) -> None: ...

class SystemProperties:
    nCols: typing.ClassVar[int] = ...
    def __init__(self, systemInterface: SystemInterface): ...
    def getProperties(self) -> java.util.HashMap[str, float]: ...
    @staticmethod
    def getPropertyNames() -> typing.MutableSequence[str]: ...
    def getValues(self) -> typing.MutableSequence[float]: ...

class SystemThermo(SystemInterface):
    characterization: jneqsim.neqsim.thermo.characterization.Characterise = ...
    componentNameTag: str = ...
    maxNumberOfPhases: int = ...
    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, double: float, double2: float, boolean: bool): ...
    def addCapeOpenProperty(self, string: str) -> None: ...
    def addCharacterized(self, stringArray: typing.Union[typing.List[str], jpype.JArray], doubleArray: typing.Union[typing.List[float], jpype.JArray], doubleArray2: typing.Union[typing.List[float], jpype.JArray], doubleArray3: typing.Union[typing.List[float], jpype.JArray]) -> None: ...
    @typing.overload
    def addComponent(self, string: str) -> None: ...
    @typing.overload
    def addComponent(self, int: int, double: float) -> None: ...
    @typing.overload
    def addComponent(self, int: int, double: float, int2: int) -> None: ...
    @typing.overload
    def addComponent(self, string: str, double: float) -> None: ...
    @typing.overload
    def addComponent(self, string: str, double: float, double2: float, double3: float, double4: float) -> None: ...
    @typing.overload
    def addComponent(self, string: str, double: float, int: int) -> None: ...
    @typing.overload
    def addComponent(self, string: str, double: float, string2: str) -> None: ...
    @typing.overload
    def addComponent(self, string: str, double: float, string2: str, int: int) -> None: ...
    @typing.overload
    def addComponent(self, componentInterface: jneqsim.neqsim.thermo.component.ComponentInterface) -> None: ...
    @typing.overload
    def addFluid(self, systemInterface: SystemInterface) -> SystemInterface: ...
    @typing.overload
    def addFluid(self, systemInterface: SystemInterface, int: int) -> SystemInterface: ...
    def addGasToLiquid(self, double: float) -> None: ...
    def addHydratePhase(self) -> None: ...
    def addHydratePhase2(self) -> None: ...
    def addLiquidToGas(self, double: float) -> None: ...
    @typing.overload
    def addOilFractions(self, stringArray: typing.Union[typing.List[str], jpype.JArray], doubleArray: typing.Union[typing.List[float], jpype.JArray], doubleArray2: typing.Union[typing.List[float], jpype.JArray], doubleArray3: typing.Union[typing.List[float], jpype.JArray], boolean: bool) -> None: ...
    @typing.overload
    def addOilFractions(self, stringArray: typing.Union[typing.List[str], jpype.JArray], doubleArray: typing.Union[typing.List[float], jpype.JArray], doubleArray2: typing.Union[typing.List[float], jpype.JArray], doubleArray3: typing.Union[typing.List[float], jpype.JArray], boolean: bool, boolean2: bool, int: int) -> None: ...
    def addPhase(self) -> None: ...
    @typing.overload
    def addPhaseFractionToPhase(self, double: float, string: str, string2: str, string3: str) -> None: ...
    @typing.overload
    def addPhaseFractionToPhase(self, double: float, string: str, string2: str, string3: str, string4: str) -> None: ...
    def addPlusFraction(self, string: str, double: float, double2: float, double3: float) -> None: ...
    def addSalt(self, string: str, double: float) -> None: ...
    def addSolidComplexPhase(self, string: str) -> None: ...
    def addSolidPhase(self) -> None: ...
    @typing.overload
    def addTBPfraction(self, string: str, double: float, double2: float, double3: float) -> None: ...
    @typing.overload
    def addTBPfraction(self, string: str, double: float, double2: float, double3: float, double4: float, double5: float, double6: float) -> None: ...
    def addToComponentNames(self, string: str) -> None: ...
    @typing.overload
    def allowPhaseShift(self) -> bool: ...
    @typing.overload
    def allowPhaseShift(self, boolean: bool) -> None: ...
    def autoSelectMixingRule(self) -> None: ...
    def autoSelectModel(self) -> SystemInterface: ...
    def calcBeta(self) -> float: ...
    def calcHenrysConstant(self, string: str) -> float: ...
    def calcInterfaceProperties(self) -> None: ...
    def calcKIJ(self, boolean: bool) -> None: ...
    def calc_x_y(self) -> None: ...
    def calc_x_y_nonorm(self) -> None: ...
    def changeComponentName(self, string: str, string2: str) -> None: ...
    @typing.overload
    def checkStability(self) -> bool: ...
    @typing.overload
    def checkStability(self, boolean: bool) -> None: ...
    def chemicalReactionInit(self) -> None: ...
    def clearAll(self) -> None: ...
    def clone(self) -> 'SystemThermo': ...
    def createDatabase(self, boolean: bool) -> None: ...
    def createTable(self, string: str) -> typing.MutableSequence[typing.MutableSequence[str]]: ...
    def deleteFluidPhase(self, int: int) -> None: ...
    @typing.overload
    def display(self) -> None: ...
    @typing.overload
    def display(self, string: str) -> None: ...
    def doMultiPhaseCheck(self) -> bool: ...
    def doSolidPhaseCheck(self) -> bool: ...
    def getAntoineVaporPressure(self, double: float) -> float: ...
    @typing.overload
    def getBeta(self) -> float: ...
    @typing.overload
    def getBeta(self, int: int) -> float: ...
    def getCASNumbers(self) -> typing.MutableSequence[str]: ...
    def getCapeOpenProperties10(self) -> typing.MutableSequence[str]: ...
    def getCapeOpenProperties11(self) -> typing.MutableSequence[str]: ...
    def getCharacterization(self) -> jneqsim.neqsim.thermo.characterization.Characterise: ...
    def getChemicalReactionOperations(self) -> jneqsim.neqsim.chemicalReactions.ChemicalReactionOperations: ...
    def getCompFormulaes(self) -> typing.MutableSequence[str]: ...
    def getCompIDs(self) -> typing.MutableSequence[str]: ...
    def getCompNames(self) -> typing.MutableSequence[str]: ...
    def getComponentNameTag(self) -> str: ...
    def getCorrectedVolume(self) -> float: ...
    def getCorrectedVolumeFraction(self, int: int) -> float: ...
    @typing.overload
    def getCp(self) -> float: ...
    @typing.overload
    def getCp(self, string: str) -> float: ...
    @typing.overload
    def getCv(self) -> float: ...
    @typing.overload
    def getCv(self, string: str) -> float: ...
    @typing.overload
    def getDensity(self) -> float: ...
    @typing.overload
    def getDensity(self, string: str) -> float: ...
    def getEmptySystemClone(self) -> SystemInterface: ...
    @typing.overload
    def getEnthalpy(self) -> float: ...
    @typing.overload
    def getEnthalpy(self, string: str) -> float: ...
    @typing.overload
    def getEntropy(self) -> float: ...
    @typing.overload
    def getEntropy(self, string: str) -> float: ...
    @typing.overload
    def getExergy(self, double: float) -> float: ...
    @typing.overload
    def getExergy(self, double: float, string: str) -> float: ...
    def getFlowRate(self, string: str) -> float: ...
    def getFluidInfo(self) -> str: ...
    def getFluidName(self) -> str: ...
    def getGamma(self) -> float: ...
    def getGasPhase(self) -> jneqsim.neqsim.thermo.phase.PhaseInterface: ...
    def getGibbsEnergy(self) -> float: ...
    def getHeatOfVaporization(self) -> float: ...
    def getHelmholtzEnergy(self) -> float: ...
    def getHydrateCheck(self) -> bool: ...
    def getIdealLiquidDensity(self, string: str) -> float: ...
    def getInitType(self) -> int: ...
    @typing.overload
    def getInterfacialTension(self, int: int, int2: int) -> float: ...
    @typing.overload
    def getInterfacialTension(self, int: int, int2: int, string: str) -> float: ...
    @typing.overload
    def getInterfacialTension(self, string: str, string2: str) -> float: ...
    @typing.overload
    def getInternalEnergy(self) -> float: ...
    @typing.overload
    def getInternalEnergy(self, string: str) -> float: ...
    def getInterphaseProperties(self) -> jneqsim.neqsim.physicalProperties.interfaceProperties.InterphasePropertiesInterface: ...
    @typing.overload
    def getJouleThomsonCoefficient(self) -> float: ...
    @typing.overload
    def getJouleThomsonCoefficient(self, string: str) -> float: ...
    def getKappa(self) -> float: ...
    @typing.overload
    def getKinematicViscosity(self) -> float: ...
    @typing.overload
    def getKinematicViscosity(self, string: str) -> float: ...
    def getLiquidPhase(self) -> jneqsim.neqsim.thermo.phase.PhaseInterface: ...
    def getLiquidVolume(self) -> float: ...
    def getLowestGibbsEnergyPhase(self) -> jneqsim.neqsim.thermo.phase.PhaseInterface: ...
    def getMass(self, string: str) -> float: ...
    def getMaxNumberOfPhases(self) -> int: ...
    def getMixingRule(self) -> int: ...
    def getMixingRuleName(self) -> str: ...
    def getModelName(self) -> str: ...
    def getMolarComposition(self) -> typing.MutableSequence[float]: ...
    @typing.overload
    def getMolarMass(self) -> float: ...
    @typing.overload
    def getMolarMass(self, string: str) -> float: ...
    def getMolarRate(self) -> typing.MutableSequence[float]: ...
    @typing.overload
    def getMolarVolume(self) -> float: ...
    @typing.overload
    def getMolarVolume(self, string: str) -> float: ...
    def getMoleFraction(self, int: int) -> float: ...
    def getMoleFractionsSum(self) -> float: ...
    def getMolecularWeights(self) -> typing.MutableSequence[float]: ...
    def getNormalBoilingPointTemperatures(self) -> typing.MutableSequence[float]: ...
    def getNumberOfComponents(self) -> int: ...
    def getNumberOfOilFractionComponents(self) -> int: ...
    def getNumberOfPhases(self) -> int: ...
    def getOilFractionIDs(self) -> typing.MutableSequence[int]: ...
    def getOilFractionLiquidDensityAt25C(self) -> typing.MutableSequence[float]: ...
    def getOilFractionMolecularMass(self) -> typing.MutableSequence[float]: ...
    def getOilFractionNormalBoilingPoints(self) -> typing.MutableSequence[float]: ...
    def getPC(self) -> float: ...
    @typing.overload
    def getPhase(self, int: int) -> jneqsim.neqsim.thermo.phase.PhaseInterface: ...
    @typing.overload
    def getPhase(self, string: str) -> jneqsim.neqsim.thermo.phase.PhaseInterface: ...
    @typing.overload
    def getPhase(self, phaseType: jneqsim.neqsim.thermo.phase.PhaseType) -> jneqsim.neqsim.thermo.phase.PhaseInterface: ...
    def getPhaseFraction(self, string: str, string2: str) -> float: ...
    @typing.overload
    def getPhaseIndex(self, int: int) -> int: ...
    @typing.overload
    def getPhaseIndex(self, string: str) -> int: ...
    @typing.overload
    def getPhaseIndex(self, phaseInterface: jneqsim.neqsim.thermo.phase.PhaseInterface) -> int: ...
    @typing.overload
    def getPhaseNumberOfPhase(self, string: str) -> int: ...
    @typing.overload
    def getPhaseNumberOfPhase(self, phaseType: jneqsim.neqsim.thermo.phase.PhaseType) -> int: ...
    def getPhaseOfType(self, string: str) -> jneqsim.neqsim.thermo.phase.PhaseInterface: ...
    def getPhases(self) -> typing.MutableSequence[jneqsim.neqsim.thermo.phase.PhaseInterface]: ...
    @typing.overload
    def getPressure(self) -> float: ...
    @typing.overload
    def getPressure(self, int: int) -> float: ...
    @typing.overload
    def getPressure(self, string: str) -> float: ...
    def getProperties(self) -> SystemProperties: ...
    @typing.overload
    def getProperty(self, string: str) -> float: ...
    @typing.overload
    def getProperty(self, string: str, int: int) -> float: ...
    @typing.overload
    def getProperty(self, string: str, string2: str, int: int) -> float: ...
    def getResultTable(self) -> typing.MutableSequence[typing.MutableSequence[str]]: ...
    @typing.overload
    def getSoundSpeed(self) -> float: ...
    @typing.overload
    def getSoundSpeed(self, string: str) -> float: ...
    @typing.overload
    def getStandard(self) -> jneqsim.neqsim.standards.StandardInterface: ...
    @typing.overload
    def getStandard(self, string: str) -> jneqsim.neqsim.standards.StandardInterface: ...
    def getSumBeta(self) -> float: ...
    def getTC(self) -> float: ...
    @typing.overload
    def getTemperature(self, int: int) -> float: ...
    @typing.overload
    def getTemperature(self) -> float: ...
    @typing.overload
    def getTemperature(self, string: str) -> float: ...
    @typing.overload
    def getThermalConductivity(self) -> float: ...
    @typing.overload
    def getThermalConductivity(self, string: str) -> float: ...
    def getTotalNumberOfMoles(self) -> float: ...
    @typing.overload
    def getViscosity(self) -> float: ...
    @typing.overload
    def getViscosity(self, string: str) -> float: ...
    @typing.overload
    def getVolume(self, string: str) -> float: ...
    @typing.overload
    def getVolume(self) -> float: ...
    def getVolumeFraction(self, int: int) -> float: ...
    def getWaxCharacterisation(self) -> jneqsim.neqsim.thermo.characterization.WaxCharacterise: ...
    def getWaxModel(self) -> jneqsim.neqsim.thermo.characterization.WaxModelInterface: ...
    def getWtFraction(self, int: int) -> float: ...
    def getZ(self) -> float: ...
    def getdPdVtn(self) -> float: ...
    def getdVdPtn(self) -> float: ...
    def getdVdTpn(self) -> float: ...
    @typing.overload
    def hasPhaseType(self, phaseType: jneqsim.neqsim.thermo.phase.PhaseType) -> bool: ...
    @typing.overload
    def hasPhaseType(self, string: str) -> bool: ...
    def hasPlusFraction(self) -> bool: ...
    def hasTBPFraction(self) -> bool: ...
    @typing.overload
    def init(self) -> None: ...
    @typing.overload
    def init(self, int: int) -> None: ...
    @typing.overload
    def init(self, int: int, int2: int) -> None: ...
    @typing.overload
    def initAnalytic(self, int: int) -> None: ...
    @typing.overload
    def initAnalytic(self, int: int, int2: int) -> None: ...
    def initBeta(self) -> None: ...
    @typing.overload
    def initNumeric(self) -> None: ...
    @typing.overload
    def initNumeric(self, int: int) -> None: ...
    @typing.overload
    def initNumeric(self, int: int, int2: int) -> None: ...
    @typing.overload
    def initPhysicalProperties(self) -> None: ...
    @typing.overload
    def initPhysicalProperties(self, string: str) -> None: ...
    def initProperties(self) -> None: ...
    def initRefPhases(self) -> None: ...
    def initTotalNumberOfMoles(self, double: float) -> None: ...
    def init_x_y(self) -> None: ...
    def invertPhaseTypes(self) -> None: ...
    @typing.overload
    def isChemicalSystem(self) -> bool: ...
    @typing.overload
    def isChemicalSystem(self, boolean: bool) -> None: ...
    def isForcePhaseTypes(self) -> bool: ...
    @typing.overload
    def isImplementedCompositionDeriativesofFugacity(self) -> bool: ...
    @typing.overload
    def isImplementedCompositionDeriativesofFugacity(self, boolean: bool) -> None: ...
    def isImplementedPressureDeriativesofFugacity(self) -> bool: ...
    def isImplementedTemperatureDeriativesofFugacity(self) -> bool: ...
    def isMultiphaseWaxCheck(self) -> bool: ...
    def isNumericDerivatives(self) -> bool: ...
    def isPhase(self, int: int) -> bool: ...
    def normalizeBeta(self) -> None: ...
    def orderByDensity(self) -> None: ...
    @typing.overload
    def phaseToSystem(self, int: int) -> SystemInterface: ...
    @typing.overload
    def phaseToSystem(self, int: int, int2: int) -> SystemInterface: ...
    @typing.overload
    def phaseToSystem(self, string: str) -> SystemInterface: ...
    @typing.overload
    def phaseToSystem(self, phaseInterface: jneqsim.neqsim.thermo.phase.PhaseInterface) -> SystemInterface: ...
    def reInitPhaseInformation(self) -> None: ...
    def reInitPhaseType(self) -> None: ...
    def readFluid(self, string: str) -> None: ...
    def readObject(self, int: int) -> SystemInterface: ...
    def readObjectFromFile(self, string: str, string2: str) -> SystemInterface: ...
    def removeComponent(self, string: str) -> None: ...
    def removePhase(self, int: int) -> None: ...
    def removePhaseKeepTotalComposition(self, int: int) -> None: ...
    def renameComponent(self, string: str, string2: str) -> None: ...
    def replacePhase(self, int: int, phaseInterface: jneqsim.neqsim.thermo.phase.PhaseInterface) -> None: ...
    def reset(self) -> None: ...
    def resetCharacterisation(self) -> None: ...
    def resetDatabase(self) -> None: ...
    def resetPhysicalProperties(self) -> None: ...
    def reset_x_y(self) -> None: ...
    def save(self, string: str) -> None: ...
    @typing.overload
    def saveFluid(self, int: int) -> None: ...
    @typing.overload
    def saveFluid(self, int: int, string: str) -> None: ...
    def saveObject(self, int: int, string: str) -> None: ...
    def saveObjectToFile(self, string: str, string2: str) -> None: ...
    def saveToDataBase(self) -> None: ...
    def setAllComponentsInPhase(self, int: int) -> None: ...
    def setAllPhaseType(self, phaseType: jneqsim.neqsim.thermo.phase.PhaseType) -> None: ...
    def setAttractiveTerm(self, int: int) -> None: ...
    @typing.overload
    def setBeta(self, double: float) -> None: ...
    @typing.overload
    def setBeta(self, int: int, double: float) -> None: ...
    def setBmixType(self, int: int) -> None: ...
    def setComponentNameTag(self, string: str) -> None: ...
    def setComponentNameTagOnNormalComponents(self, string: str) -> None: ...
    def setComponentNames(self, stringArray: typing.Union[typing.List[str], jpype.JArray]) -> None: ...
    def setEmptyFluid(self) -> None: ...
    def setFluidInfo(self, string: str) -> None: ...
    def setFluidName(self, string: str) -> None: ...
    def setForcePhaseTypes(self, boolean: bool) -> None: ...
    def setHeavyTBPfractionAsPlusFraction(self) -> bool: ...
    def setHydrateCheck(self, boolean: bool) -> None: ...
    def setImplementedCompositionDeriativesofFugacity(self, boolean: bool) -> None: ...
    def setImplementedPressureDeriativesofFugacity(self, boolean: bool) -> None: ...
    def setImplementedTemperatureDeriativesofFugacity(self, boolean: bool) -> None: ...
    def setInitType(self, int: int) -> None: ...
    def setLastTBPasPlus(self) -> bool: ...
    def setMaxNumberOfPhases(self, int: int) -> None: ...
    @typing.overload
    def setMixingRule(self, int: int) -> None: ...
    @typing.overload
    def setMixingRule(self, string: str) -> None: ...
    @typing.overload
    def setMixingRule(self, string: str, string2: str) -> None: ...
    def setMixingRuleGEmodel(self, string: str) -> None: ...
    def setModel(self, string: str) -> SystemInterface: ...
    def setModelName(self, string: str) -> None: ...
    def setMolarComposition(self, doubleArray: typing.Union[typing.List[float], jpype.JArray]) -> None: ...
    def setMolarCompositionOfPlusFluid(self, doubleArray: typing.Union[typing.List[float], jpype.JArray]) -> None: ...
    def setMolarCompositionPlus(self, doubleArray: typing.Union[typing.List[float], jpype.JArray]) -> None: ...
    def setMolarFlowRates(self, doubleArray: typing.Union[typing.List[float], jpype.JArray]) -> None: ...
    def setMultiPhaseCheck(self, boolean: bool) -> None: ...
    def setMultiphaseWaxCheck(self, boolean: bool) -> None: ...
    def setNumberOfPhases(self, int: int) -> None: ...
    def setNumericDerivatives(self, boolean: bool) -> None: ...
    def setPC(self, double: float) -> None: ...
    def setPhase(self, phaseInterface: jneqsim.neqsim.thermo.phase.PhaseInterface, int: int) -> None: ...
    def setPhaseIndex(self, int: int, int2: int) -> None: ...
    @typing.overload
    def setPhaseType(self, int: int, string: str) -> None: ...
    @typing.overload
    def setPhaseType(self, int: int, phaseType: jneqsim.neqsim.thermo.phase.PhaseType) -> None: ...
    def setPhysicalPropertyModel(self, int: int) -> None: ...
    @typing.overload
    def setPressure(self, double: float) -> None: ...
    @typing.overload
    def setPressure(self, double: float, string: str) -> None: ...
    @typing.overload
    def setSolidPhaseCheck(self, boolean: bool) -> None: ...
    @typing.overload
    def setSolidPhaseCheck(self, string: str) -> None: ...
    def setStandard(self, string: str) -> None: ...
    def setTC(self, double: float) -> None: ...
    @typing.overload
    def setTemperature(self, double: float, int: int) -> None: ...
    @typing.overload
    def setTemperature(self, double: float) -> None: ...
    @typing.overload
    def setTemperature(self, double: float, string: str) -> None: ...
    def setTotalFlowRate(self, double: float, string: str) -> None: ...
    def setTotalNumberOfMoles(self, double: float) -> None: ...
    def setUseTVasIndependentVariables(self, boolean: bool) -> None: ...
    def tuneModel(self, string: str, double: float, int: int) -> None: ...
    def useTVasIndependentVariables(self) -> bool: ...
    def useVolumeCorrection(self, boolean: bool) -> None: ...
    @typing.overload
    def write(self) -> str: ...
    @typing.overload
    def write(self, string: str, string2: str, boolean: bool) -> None: ...

class SystemEos(SystemThermo):
    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, double: float, double2: float, boolean: bool): ...

class SystemBWRSEos(SystemEos):
    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, double: float, double2: float): ...
    @typing.overload
    def __init__(self, double: float, double2: float, boolean: bool): ...
    def clone(self) -> 'SystemBWRSEos': ...

class SystemDesmukhMather(SystemEos):
    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, double: float, double2: float): ...
    @typing.overload
    def __init__(self, double: float, double2: float, boolean: bool): ...
    def clone(self) -> 'SystemDesmukhMather': ...

class SystemDuanSun(SystemEos):
    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, double: float, double2: float): ...
    @typing.overload
    def __init__(self, double: float, double2: float, boolean: bool): ...
    def clone(self) -> 'SystemDuanSun': ...

class SystemGERG2004Eos(SystemEos):
    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, double: float, double2: float): ...
    @typing.overload
    def __init__(self, double: float, double2: float, boolean: bool): ...
    def clone(self) -> 'SystemGERG2004Eos': ...
    def commonInitialization(self) -> None: ...

class SystemGEWilson(SystemEos):
    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, double: float, double2: float): ...
    @typing.overload
    def __init__(self, double: float, double2: float, boolean: bool): ...
    def clone(self) -> 'SystemGEWilson': ...

class SystemKentEisenberg(SystemEos):
    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, double: float, double2: float): ...
    @typing.overload
    def __init__(self, double: float, double2: float, boolean: bool): ...
    def clone(self) -> 'SystemKentEisenberg': ...

class SystemNRTL(SystemEos):
    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, double: float, double2: float): ...
    @typing.overload
    def __init__(self, double: float, double2: float, boolean: bool): ...
    def clone(self) -> 'SystemNRTL': ...

class SystemPrEos(SystemEos):
    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, double: float, double2: float): ...
    @typing.overload
    def __init__(self, double: float, double2: float, boolean: bool): ...
    def clone(self) -> 'SystemPrEos': ...

class SystemPrEos1978(SystemEos):
    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, double: float, double2: float): ...
    @typing.overload
    def __init__(self, double: float, double2: float, boolean: bool): ...
    def clone(self) -> 'SystemPrEos1978': ...

class SystemRKEos(SystemEos):
    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, double: float, double2: float): ...
    @typing.overload
    def __init__(self, double: float, double2: float, boolean: bool): ...
    def clone(self) -> 'SystemRKEos': ...

class SystemSrkEos(SystemEos):
    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, double: float, double2: float): ...
    @typing.overload
    def __init__(self, double: float, double2: float, boolean: bool): ...
    def clone(self) -> 'SystemSrkEos': ...

class SystemTSTEos(SystemEos):
    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, double: float, double2: float): ...
    @typing.overload
    def __init__(self, double: float, double2: float, boolean: bool): ...
    def clone(self) -> 'SystemTSTEos': ...

class SystemUNIFAC(SystemEos):
    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, double: float, double2: float): ...
    @typing.overload
    def __init__(self, double: float, double2: float, boolean: bool): ...
    def clone(self) -> 'SystemUNIFAC': ...

class SystemUNIFACpsrk(SystemEos):
    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, double: float, double2: float): ...
    @typing.overload
    def __init__(self, double: float, double2: float, boolean: bool): ...
    def clone(self) -> 'SystemUNIFACpsrk': ...

class SystemCSPsrkEos(SystemSrkEos):
    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, double: float, double2: float): ...
    @typing.overload
    def __init__(self, double: float, double2: float, boolean: bool): ...
    def clone(self) -> 'SystemCSPsrkEos': ...

class SystemFurstElectrolyteEos(SystemSrkEos):
    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, double: float, double2: float): ...
    def clone(self) -> 'SystemFurstElectrolyteEos': ...

class SystemFurstElectrolyteEosMod2004(SystemSrkEos):
    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, double: float, double2: float): ...
    def clone(self) -> 'SystemFurstElectrolyteEosMod2004': ...

class SystemGERGwaterEos(SystemPrEos):
    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, double: float, double2: float): ...
    @typing.overload
    def __init__(self, double: float, double2: float, boolean: bool): ...
    def clone(self) -> 'SystemGERGwaterEos': ...

class SystemPCSAFT(SystemSrkEos):
    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, double: float, double2: float): ...
    @typing.overload
    def __init__(self, double: float, double2: float, boolean: bool): ...
    @typing.overload
    def addTBPfraction(self, string: str, double: float, double2: float, double3: float) -> None: ...
    @typing.overload
    def addTBPfraction(self, string: str, double: float, double2: float, double3: float, double4: float, double5: float, double6: float) -> None: ...
    def clone(self) -> 'SystemPCSAFT': ...
    def commonInitialization(self) -> None: ...

class SystemPCSAFTa(SystemSrkEos):
    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, double: float, double2: float): ...
    @typing.overload
    def __init__(self, double: float, double2: float, boolean: bool): ...
    def clone(self) -> 'SystemPCSAFTa': ...

class SystemPrCPA(SystemPrEos):
    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, double: float, double2: float): ...
    @typing.overload
    def __init__(self, double: float, double2: float, boolean: bool): ...
    def clone(self) -> 'SystemPrCPA': ...

class SystemPrDanesh(SystemPrEos):
    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, double: float, double2: float): ...
    @typing.overload
    def __init__(self, double: float, double2: float, boolean: bool): ...
    def clone(self) -> 'SystemPrDanesh': ...

class SystemPrEosDelft1998(SystemPrEos):
    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, double: float, double2: float): ...
    @typing.overload
    def __init__(self, double: float, double2: float, boolean: bool): ...
    def clone(self) -> 'SystemPrEosDelft1998': ...

class SystemPrGassemEos(SystemPrEos):
    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, double: float, double2: float): ...
    @typing.overload
    def __init__(self, double: float, double2: float, boolean: bool): ...
    def clone(self) -> 'SystemPrGassemEos': ...

class SystemPrMathiasCopeman(SystemPrEos):
    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, double: float, double2: float): ...
    @typing.overload
    def __init__(self, double: float, double2: float, boolean: bool): ...
    def clone(self) -> 'SystemPrMathiasCopeman': ...

class SystemPsrkEos(SystemSrkEos):
    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, double: float, double2: float): ...
    @typing.overload
    def __init__(self, double: float, double2: float, boolean: bool): ...
    def clone(self) -> 'SystemPsrkEos': ...

class SystemSrkCPA(SystemSrkEos):
    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, double: float, double2: float): ...
    @typing.overload
    def __init__(self, double: float, double2: float, boolean: bool): ...
    @typing.overload
    def addComponent(self, string: str) -> None: ...
    @typing.overload
    def addComponent(self, string: str, double: float) -> None: ...
    @typing.overload
    def addComponent(self, int: int, double: float) -> None: ...
    @typing.overload
    def addComponent(self, int: int, double: float, int2: int) -> None: ...
    @typing.overload
    def addComponent(self, string: str, double: float, double2: float, double3: float, double4: float) -> None: ...
    @typing.overload
    def addComponent(self, string: str, double: float, int: int) -> None: ...
    @typing.overload
    def addComponent(self, string: str, double: float, string2: str) -> None: ...
    @typing.overload
    def addComponent(self, string: str, double: float, string2: str, int: int) -> None: ...
    @typing.overload
    def addComponent(self, componentInterface: jneqsim.neqsim.thermo.component.ComponentInterface) -> None: ...
    def clone(self) -> 'SystemSrkCPA': ...
    def commonInitialization(self) -> None: ...

class SystemSrkMathiasCopeman(SystemSrkEos):
    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, double: float, double2: float): ...
    @typing.overload
    def __init__(self, double: float, double2: float, boolean: bool): ...
    def clone(self) -> 'SystemSrkMathiasCopeman': ...

class SystemSrkPenelouxEos(SystemSrkEos):
    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, double: float, double2: float): ...
    @typing.overload
    def __init__(self, double: float, double2: float, boolean: bool): ...
    def clone(self) -> 'SystemSrkPenelouxEos': ...

class SystemSrkSchwartzentruberEos(SystemSrkEos):
    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, double: float, double2: float): ...
    @typing.overload
    def __init__(self, double: float, double2: float, boolean: bool): ...
    def clone(self) -> 'SystemSrkSchwartzentruberEos': ...

class SystemSrkTwuCoonEos(SystemSrkEos):
    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, double: float, double2: float): ...
    @typing.overload
    def __init__(self, double: float, double2: float, boolean: bool): ...
    def clone(self) -> 'SystemSrkTwuCoonEos': ...

class SystemSrkTwuCoonParamEos(SystemSrkEos):
    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, double: float, double2: float): ...
    @typing.overload
    def __init__(self, double: float, double2: float, boolean: bool): ...
    def clone(self) -> 'SystemSrkTwuCoonParamEos': ...

class SystemSrkTwuCoonStatoilEos(SystemSrkEos):
    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, double: float, double2: float): ...
    @typing.overload
    def __init__(self, double: float, double2: float, boolean: bool): ...
    def clone(self) -> 'SystemSrkTwuCoonStatoilEos': ...

class SystemUMRCPAEoS(SystemPrEos):
    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, double: float, double2: float): ...

class SystemUMRPRUEos(SystemPrEos):
    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, double: float, double2: float): ...
    @typing.overload
    def __init__(self, double: float, double2: float, boolean: bool): ...
    def clone(self) -> 'SystemUMRPRUEos': ...
    def commonInitialization(self) -> None: ...

class SystemElectrolyteCPA(SystemFurstElectrolyteEos):
    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, double: float, double2: float): ...
    def clone(self) -> 'SystemElectrolyteCPA': ...

class SystemElectrolyteCPAstatoil(SystemFurstElectrolyteEos):
    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, double: float, double2: float): ...
    def clone(self) -> 'SystemElectrolyteCPAstatoil': ...

class SystemSrkCPAs(SystemSrkCPA):
    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, double: float, double2: float): ...
    @typing.overload
    def __init__(self, double: float, double2: float, boolean: bool): ...
    def clone(self) -> 'SystemSrkCPAs': ...

class SystemUMRPRUMCEos(SystemUMRPRUEos):
    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, double: float, double2: float): ...
    @typing.overload
    def __init__(self, double: float, double2: float, boolean: bool): ...
    def clone(self) -> 'SystemUMRPRUMCEos': ...

class SystemSrkCPAstatoil(SystemSrkCPAs):
    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, double: float, double2: float): ...
    @typing.overload
    def __init__(self, double: float, double2: float, boolean: bool): ...
    def clone(self) -> 'SystemSrkCPAstatoil': ...

class SystemUMRPRUMCEosNew(SystemUMRPRUMCEos):
    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, double: float, double2: float): ...


class __module_protocol__(Protocol):
    # A module protocol which reflects the result of ``jp.JPackage("jneqsim.neqsim.thermo.system")``.

    SystemBWRSEos: typing.Type[SystemBWRSEos]
    SystemCSPsrkEos: typing.Type[SystemCSPsrkEos]
    SystemDesmukhMather: typing.Type[SystemDesmukhMather]
    SystemDuanSun: typing.Type[SystemDuanSun]
    SystemElectrolyteCPA: typing.Type[SystemElectrolyteCPA]
    SystemElectrolyteCPAstatoil: typing.Type[SystemElectrolyteCPAstatoil]
    SystemEos: typing.Type[SystemEos]
    SystemFurstElectrolyteEos: typing.Type[SystemFurstElectrolyteEos]
    SystemFurstElectrolyteEosMod2004: typing.Type[SystemFurstElectrolyteEosMod2004]
    SystemGERG2004Eos: typing.Type[SystemGERG2004Eos]
    SystemGERGwaterEos: typing.Type[SystemGERGwaterEos]
    SystemGEWilson: typing.Type[SystemGEWilson]
    SystemInterface: typing.Type[SystemInterface]
    SystemKentEisenberg: typing.Type[SystemKentEisenberg]
    SystemNRTL: typing.Type[SystemNRTL]
    SystemPCSAFT: typing.Type[SystemPCSAFT]
    SystemPCSAFTa: typing.Type[SystemPCSAFTa]
    SystemPrCPA: typing.Type[SystemPrCPA]
    SystemPrDanesh: typing.Type[SystemPrDanesh]
    SystemPrEos: typing.Type[SystemPrEos]
    SystemPrEos1978: typing.Type[SystemPrEos1978]
    SystemPrEosDelft1998: typing.Type[SystemPrEosDelft1998]
    SystemPrGassemEos: typing.Type[SystemPrGassemEos]
    SystemPrMathiasCopeman: typing.Type[SystemPrMathiasCopeman]
    SystemProperties: typing.Type[SystemProperties]
    SystemPsrkEos: typing.Type[SystemPsrkEos]
    SystemRKEos: typing.Type[SystemRKEos]
    SystemSrkCPA: typing.Type[SystemSrkCPA]
    SystemSrkCPAs: typing.Type[SystemSrkCPAs]
    SystemSrkCPAstatoil: typing.Type[SystemSrkCPAstatoil]
    SystemSrkEos: typing.Type[SystemSrkEos]
    SystemSrkMathiasCopeman: typing.Type[SystemSrkMathiasCopeman]
    SystemSrkPenelouxEos: typing.Type[SystemSrkPenelouxEos]
    SystemSrkSchwartzentruberEos: typing.Type[SystemSrkSchwartzentruberEos]
    SystemSrkTwuCoonEos: typing.Type[SystemSrkTwuCoonEos]
    SystemSrkTwuCoonParamEos: typing.Type[SystemSrkTwuCoonParamEos]
    SystemSrkTwuCoonStatoilEos: typing.Type[SystemSrkTwuCoonStatoilEos]
    SystemTSTEos: typing.Type[SystemTSTEos]
    SystemThermo: typing.Type[SystemThermo]
    SystemUMRCPAEoS: typing.Type[SystemUMRCPAEoS]
    SystemUMRPRUEos: typing.Type[SystemUMRPRUEos]
    SystemUMRPRUMCEos: typing.Type[SystemUMRPRUMCEos]
    SystemUMRPRUMCEosNew: typing.Type[SystemUMRPRUMCEosNew]
    SystemUNIFAC: typing.Type[SystemUNIFAC]
    SystemUNIFACpsrk: typing.Type[SystemUNIFACpsrk]
